[Bf-blender-cvs] [cdafbc0] depsgraph_refactor: Cleanup: typos

Campbell Barton noreply at git.blender.org
Thu Apr 30 21:21:38 CEST 2015


Commit: cdafbc026f820f6843ad8fd550df97531a4ac09d
Author: Campbell Barton
Date:   Fri May 1 04:45:33 2015 +1000
Branches: depsgraph_refactor
https://developer.blender.org/rBcdafbc026f820f6843ad8fd550df97531a4ac09d

Cleanup: typos

===================================================================

M	source/blender/depsgraph/DEG_depsgraph.h
M	source/blender/depsgraph/DEG_depsgraph_query.h
M	source/blender/depsgraph/intern/depsgraph.cpp
M	source/blender/depsgraph/intern/depsgraph_build.cpp
M	source/blender/depsgraph/intern/depsgraph_build_nodes.cpp
M	source/blender/depsgraph/intern/depsgraph_build_relations.cpp
M	source/blender/depsgraph/intern/depsgraph_tag.cpp
M	source/blender/depsgraph/intern/depsgraph_types.h
M	source/blender/depsgraph/intern/depsnode.cpp
M	source/blender/depsgraph/intern/depsnode.h
M	source/blender/depsgraph/intern/depsnode_component.cpp
M	source/blender/depsgraph/intern/depsnode_component.h
M	source/gameengine/Converter/BL_BlenderDataConversion.cpp

===================================================================

diff --git a/source/blender/depsgraph/DEG_depsgraph.h b/source/blender/depsgraph/DEG_depsgraph.h
index 3ac42aa..30218e1 100644
--- a/source/blender/depsgraph/DEG_depsgraph.h
+++ b/source/blender/depsgraph/DEG_depsgraph.h
@@ -76,7 +76,7 @@ void DEG_depsgraph_switch_to_legacy(void);
 // Get main depsgraph instance from context!
 
 /* Create new Depsgraph instance */
-// TODO: what args are needed here? What's the building-graph entrypoint?
+// TODO: what args are needed here? What's the building-graph entry point?
 Depsgraph *DEG_graph_new(void);
 
 /* Free Depsgraph itself and all its data */
@@ -116,7 +116,7 @@ void DEG_id_tag_update_ex(struct Main *bmain,
 
 /* Tag given ID type for update.
  *
- * Used by all sort of render engines to quicly check if
+ * Used by all sort of render engines to quickly check if
  * IDs of a given type need to be checked for update.
  */
 void DEG_id_type_tag(struct Main *bmain, short idtype);
@@ -162,7 +162,7 @@ void DEG_evaluation_context_free(struct EvaluationContext *eval_ctx);
 
 /* Graph Evaluation  ----------------------------- */
 
-/* Frame changed recalculation entrypoint 
+/* Frame changed recalculation entry point
  * < context_type: context to perform evaluation for
  * < ctime: (frame) new frame to evaluate values on
  */
@@ -172,7 +172,7 @@ void DEG_evaluate_on_framechange(struct EvaluationContext *eval_ctx,
                                  float ctime,
                                  const int layer);
 
-/* Data changed recalculation entrypoint.
+/* Data changed recalculation entry point.
  * < context_type: context to perform evaluation for
  * < layers: visible layers bitmask to update the graph for
  */
@@ -180,7 +180,7 @@ void DEG_evaluate_on_refresh_ex(struct EvaluationContext *eval_ctx,
                                 Depsgraph *graph,
                                 const int layers);
 
-/* Data changed recalculation entrypoint.
+/* Data changed recalculation entry point.
  * < context_type: context to perform evaluation for
  */
 void DEG_evaluate_on_refresh(struct EvaluationContext *eval_ctx,
diff --git a/source/blender/depsgraph/intern/depsgraph.cpp b/source/blender/depsgraph/intern/depsgraph.cpp
index c62bf3b..c519f1d 100644
--- a/source/blender/depsgraph/intern/depsgraph.cpp
+++ b/source/blender/depsgraph/intern/depsgraph.cpp
@@ -434,7 +434,7 @@ void Depsgraph::clear_all_nodes()
 /* **************** */
 /* Public Graph API */
 
-/* Initialise a new Depsgraph */
+/* Initialize a new Depsgraph */
 Depsgraph *DEG_graph_new()
 {
 	return OBJECT_GUARDED_NEW(Depsgraph);
diff --git a/source/blender/depsgraph/intern/depsgraph_build.cpp b/source/blender/depsgraph/intern/depsgraph_build.cpp
index f517d91..e1a6528 100644
--- a/source/blender/depsgraph/intern/depsgraph_build.cpp
+++ b/source/blender/depsgraph/intern/depsgraph_build.cpp
@@ -241,7 +241,7 @@ static void deg_graph_build_finalize(Depsgraph *graph)
 				}
 			}
 
-			/* Re-tag ID for update if it was tagged befoee the relations
+			/* Re-tag ID for update if it was tagged before the relations
 			 * update tag.
 			 */
 			ID *id = id_node->id;
diff --git a/source/blender/depsgraph/intern/depsgraph_build_nodes.cpp b/source/blender/depsgraph/intern/depsgraph_build_nodes.cpp
index 1e80594..0d21f01 100644
--- a/source/blender/depsgraph/intern/depsgraph_build_nodes.cpp
+++ b/source/blender/depsgraph/intern/depsgraph_build_nodes.cpp
@@ -387,7 +387,7 @@ void DepsgraphNodeBuilder::build_object(Scene *scene, Base *base, Object *ob)
 			case OB_LATTICE:
 			{
 				/* TODO(sergey): This way using this object's
-				 * proeprties as driver target works fine.
+				 * properties as driver target works fine.
 				 *
 				 * Does this depend on other nodes?
 				 */
@@ -565,7 +565,7 @@ OperationDepsNode *DepsgraphNodeBuilder::build_driver(ID *id, FCurve *fcu)
 
 	/* Create data node for this driver */
 	/* TODO(sergey): Avoid creating same operation multiple times,
-	 * in the future we need to avoid lookup of the operaiton as well
+	 * in the future we need to avoid lookup of the operation as well
 	 * and use some tagging magic instead.
 	 */
 	OperationDepsNode *driver_op = find_operation_node(id,
@@ -619,7 +619,7 @@ void DepsgraphNodeBuilder::build_rigidbody(Scene *scene)
 
 	/* == Rigidbody Simulation Nodes ==
 	 * There are 3 nodes related to Rigidbody Simulation:
-	 * 1) "Initialise/Rebuild World" - this is called sparingly, only when the simulation
+	 * 1) "Initialize/Rebuild World" - this is called sparingly, only when the simulation
 	 *    needs to be rebuilt (mainly after file reload, or moving back to start frame)
 	 * 2) "Do Simulation" - perform a simulation step - interleaved between the evaluation
 	 *    steps for clusters of objects (i.e. between those affected and/or not affected by
@@ -748,7 +748,7 @@ void DepsgraphNodeBuilder::build_rig(Scene *scene, Object *ob)
 	/* animation and/or drivers linking posebones to base-armature used to define them
 	 * NOTE: AnimData here is really used to control animated deform properties,
 	 *       which ideally should be able to be unique across different instances.
-	 *       Eventually, we need some type of proxy/isolation mechanism inbetween here
+	 *       Eventually, we need some type of proxy/isolation mechanism in-between here
 	 *       to ensure that we can use same rig multiple times in same scene...
 	 */
 	build_animdata(&arm->id);
@@ -756,7 +756,7 @@ void DepsgraphNodeBuilder::build_rig(Scene *scene, Object *ob)
 	/* Rebuild pose if not up to date. */
 	if (ob->pose == NULL || (ob->pose->flag & POSE_RECALC)) {
 		BKE_pose_rebuild(ob, arm);
-		/* XXX: Without this animaiton gets los incertain circumstances
+		/* XXX: Without this animation gets lost in certain circumstances
 		 * after loading file. Need to investigate further since it does
 		 * not happen with simple scenes..
 		 */
diff --git a/source/blender/depsgraph/intern/depsgraph_build_relations.cpp b/source/blender/depsgraph/intern/depsgraph_build_relations.cpp
index 7896489..edbb346 100644
--- a/source/blender/depsgraph/intern/depsgraph_build_relations.cpp
+++ b/source/blender/depsgraph/intern/depsgraph_build_relations.cpp
@@ -828,7 +828,7 @@ void DepsgraphRelationBuilder::build_driver(ID *id, FCurve *fcu)
 				if (target_pchan != NULL) {
 					/* get node associated with bone */
 					// XXX: watch the space!
-					/* Some casescan't use final bone transform, for example:
+					/* Some cases can't use final bone transform, for example:
 					 * - Driving the bone with itself (addressed here)
 					 * - Relations inside an IK chain (TODO?)
 					 */
@@ -1098,9 +1098,9 @@ void DepsgraphRelationBuilder::build_ik_pose(Object *ob,
 	// XXX: this should get handled as part of the constraint code
 	if (data->tar != NULL) {
 		/* TODO(sergey): For until we'll store partial matricies in the depsgraph,
-		 * we create dependency bewteen target object and pose eval component.
+		 * we create dependency between target object and pose eval component.
 		 *
-		 * This way we ensuring the whole subtree is updated from sctratch without
+		 * This way we ensuring the whole subtree is updated from scratch without
 		 * need of intermediate matricies. This is an overkill, but good enough for
 		 * testing IK solver.
 		 */
@@ -1244,7 +1244,7 @@ void DepsgraphRelationBuilder::build_splineik_pose(Object *ob,
 	/* attach path dependency to solver */
 	if (data->tar) {
 		/* TODO(sergey): For until we'll store partial matricies in the depsgraph,
-		 * we create dependency bewteen target object and pose eval component.
+		 * we create dependency between target object and pose eval component.
 		 * See IK pose for a bit more information.
 		 */
 		// TODO: the bigggest point here is that we need the curve PATH and not just the general geometry...
diff --git a/source/blender/depsgraph/intern/depsgraph_tag.cpp b/source/blender/depsgraph/intern/depsgraph_tag.cpp
index d40b3e2..91aa900 100644
--- a/source/blender/depsgraph/intern/depsgraph_tag.cpp
+++ b/source/blender/depsgraph/intern/depsgraph_tag.cpp
@@ -458,7 +458,7 @@ void DEG_ids_clear_recalc(Main *bmain)
 	int a;
 
 	/* TODO(sergey): Re-implement POST_UPDATE_HANDLER_WORKAROUND using entry_tags
-	 * and id_tags storage from the new depenency graph.
+	 * and id_tags storage from the new dependency graph.
 	 */
 
 	/* Loop over all ID types. */
diff --git a/source/blender/depsgraph/intern/depsgraph_types.h b/source/blender/depsgraph/intern/depsgraph_types.h
index 9acb7b2..2a84f45 100644
--- a/source/blender/depsgraph/intern/depsgraph_types.h
+++ b/source/blender/depsgraph/intern/depsgraph_types.h
@@ -35,7 +35,7 @@
 
 #include "depsgraph_util_function.h"
 
-/* TODO(sergey): Ideally we'll just use char* and staticly allocated strings
+/* TODO(sergey): Ideally we'll just use char* and st

@@ Diff output truncated at 10240 characters. @@




More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/depsgraph/DEG_depsgraph_query.h b/source/blender/depsgraph/DEG_depsgraph_query.h
index 43b9b11..000497c 100644
--- a/source/blender/depsgraph/DEG_depsgraph_query.h
+++ b/source/blender/depsgraph/DEG_depsgraph_query.h
@@ -141,12 +141,12 @@ void DEG_node_get_dependencies(struct ListBase *result, const struct DepsNode *n
 // XXX: allow supplying a filter predicate to provide further filtering/pruning?
 
 
 /* Get all descendents of a node
  *
  * That is, get the subgraph / subset of nodes which are dependent
  * on the results of the given node.
  */
-Depsgraph *DEG_node_get_descendents(const struct Depsgraph *graph, const struct DepsNode *node);
+Depsgraph *DEG_node_get_descendants(const struct Depsgraph *graph, const struct DepsNode *node);
 
 
 /* Get all ancestors of a node 
@@ -171,7 +171,7 @@ size_t DEG_query_affected_ids(struct ListBase *result, const struct ID *id, cons
 /* Get ID-blocks which are needed to update/evaluate specified ID 
  * < only_direct: True = Only ID-blocks with direct relationships to ID-block will be returned
  *
- * > result: (LinkData : ID) a list of ID-blocks mathcing the specified criteria
+ * > result: (LinkData : ID) a list of ID-blocks matching the specified criteria
  * > returns: number of matching ID-blocks
  */
 size_t DEG_query_required_ids(struct ListBase *result, const struct ID *id, const bool only_direct);
@@ -141,12 +141,12 @@ void DEG_node_get_dependencies(struct ListBase *result, const struct DepsNode *n
 
 
-/* Get all descendents of a node
+/* Get all descendants of a node
  *
  * That is, get the subgraph / subset of nodes which are dependent